@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005, 2006 Christian Persch
+ *  Copyright © 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -13,50 +13,45 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyPromptService.cpp,v 1.10.2.3 2006/07/18 17:57:41 chpe Exp $
+ *  $Id: EphyPromptService.cpp 8229 2008-05-18 21:50:13Z chpe $
  */
 
 #include "mozilla-config.h"
 #include "config.h"
 
-#include "EphyPromptService.h"
-#include "AutoJSContextStack.h"
-#include "AutoWindowModalState.h"
-
-#include <nsCOMPtr.h>
-#include <nsIDOMWindow.h>
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-
-#if 0
-#include <nsIPrincipal.h>
-#include <nsIScriptSecurityManager.h>
-#include <nsIServiceManager.h>
-#endif
-
-#if 0
-#include "AutoEventQueue.h"
-#endif
-
-#include "EphyUtils.h"
-
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkversion.h>
+
+#include <nsStringAPI.h>
+
+#include <nsCOMPtr.h>
+#include <nsIDOMWindow.h>
+#include <nsServiceManagerUtils.h>
 
 #include "ephy-embed-shell.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 
-#ifndef HAVE_GECKO_1_8
-typedef nsEmbedString nsDependentString;
-typedef nsEmbedCString nsDependentCString;
-#endif
+#include "AutoModalDialog.h"
+#include "EphyUtils.h"
+
+#ifdef HAVE_GECKO_1_9
+#include <nsIStringBundle.h>
+#include "nsIChannel.h"
+#include "nsIProxiedChannel.h"
+#include "nsIProxyInfo.h"
+#include "nsNetCID.h"
+#include "nsIURI.h"
+#include "nsNetUtil.h"
+#include "nsIIDNService.h"
+#include "nsIAuthInformation.h"
+#endif /* HAVE_GECKO_1_9 */
+
+#include "EphyPromptService.h"
 
 #define TIMEOUT			1000 /* ms */
 #define TIMEOUT_DATA_KEY	"timeout"
@@ -70,8 +65,6 @@ enum
 	RESPONSE_ABORT_SCRIPT = 42
 };
 
-#define RETVAL(r) (NS_OK)
-
 class Prompter
 {
 public:
@@ -139,8 +132,7 @@ Prompter::Prompter (const char *aStock,
 	mEntries[0] = mEntries[1] = nsnull;
 
 	mDialog = GTK_DIALOG (gtk_dialog_new ());
-	g_object_ref (mDialog);
-	gtk_object_sink (GTK_OBJECT (mDialog));
+	g_object_ref_sink (mDialog);
 
 	char *title = NULL;
 	if (aTitle)
@@ -185,14 +177,12 @@ Prompter::Prompter (const char *aStock,
 		text = ConvertAndTruncateString (aText, MAX_MESSAGE_LENGTH);
 	}
 
-	label = gtk_label_new (text);
+	label = gtk_label_new (text ? text : "");
 	g_free (text);
 
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-#if GTK_CHECK_VERSION (2, 10, 0)
 	/* Guard against overlong nonbreakable text (exploit) */
 	gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD_CHAR);
-#endif
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 
@@ -343,7 +333,7 @@ Prompter::AddCheckbox (const PRUnichar *aText,
 	if (!aState || !aText) return;
 
 	char *label = ConvertAndEscapeButtonText (aText, 2 * MAX_BUTTON_TEXT_LENGTH);
-	mCheck = gtk_check_button_new_with_mnemonic (label);
+	mCheck = gtk_check_button_new_with_mnemonic (label ? label : "");
 	g_free (label);
 
 	gtk_label_set_line_wrap (GTK_LABEL (GTK_BIN (mCheck)->child), TRUE);
@@ -388,7 +378,7 @@ Prompter::AddEntry (const char *aLabel,
 
 	if (aValue)
 	{
-		nsEmbedCString cValue;
+		nsCString cValue;
 		NS_UTF16ToCString (nsDependentString(aValue),
 				   NS_CSTRING_ENCODING_UTF8, cValue);
 
@@ -413,7 +403,7 @@ Prompter::GetText (PRUint32 aNum,
 	const char *text = gtk_entry_get_text (GTK_ENTRY (mEntries[aNum]));
 	if (!text) return;
 
-	nsEmbedString value;
+	nsString value;
 	NS_CStringToUTF16 (nsDependentCString (text),
 			   NS_CSTRING_ENCODING_UTF8, value);
 
@@ -432,7 +422,7 @@ Prompter::AddSelect (PRUint32 aCount,
 		/* FIXME: use "" instead in this case? */
 		if (!aList[i] || !aList[i][0]) continue;
 
-		nsEmbedCString cData;
+		nsCString cData;
 		NS_UTF16ToCString (nsDependentString(aList[i]), NS_CSTRING_ENCODING_UTF8, cData);
 
 		gtk_combo_box_append_text (GTK_COMBO_BOX (mCombo), cData.get());
@@ -491,12 +481,9 @@ Prompter::Run (PRBool *aSuccess)
 	}
 #endif
 
-	nsresult rv;
-	AutoJSContextStack stack;
-	rv = stack.Init ();
-	if (NS_FAILED (rv)) return rv;
-
-	AutoWindowModalState modalState (mWindow);
+        AutoModalDialog modalDialog (mWindow, PR_TRUE);
+        if (!modalDialog.ShouldShow ())
+                return GTK_RESPONSE_CANCEL;
 
 	if (mDelay)
 	{
@@ -512,7 +499,7 @@ Prompter::Run (PRBool *aSuccess)
 
 	GtkWidget *widget = GTK_WIDGET (mDialog);
 	gtk_widget_show (widget);
-	mResponse = gtk_dialog_run (mDialog);
+	mResponse = modalDialog.Run (mDialog);
 	gtk_widget_hide (widget);
 
 	g_object_set_data (G_OBJECT (mDialog), TIMEOUT_DATA_KEY, NULL);
@@ -535,7 +522,7 @@ static void
 DeletePrompter (gpointer aPromptPtr,
 	        GObject *aZombie)
 {
-	Prompter *prompt = NS_STATIC_CAST (Prompter*, aPromptPtr);
+	Prompter *prompt = static_cast<Prompter*>(aPromptPtr);
 
 	delete prompt;
 }
@@ -552,7 +539,7 @@ Prompter::Show ()
 			  G_CALLBACK (gtk_widget_destroy), NULL);
 	g_object_weak_ref (G_OBJECT (mDialog),
 			   (GWeakNotify) DeletePrompter,
-			   NS_STATIC_CAST (gpointer, this));
+			   static_cast<gpointer>(this));
 
 	gtk_widget_show (GTK_WIDGET (mDialog));
 }
@@ -560,18 +547,24 @@ Prompter::Show ()
 PRBool
 Prompter::IsCalledFromScript()
 {
-	/* FIXME: implement me! */
 #if 0
+	nsCOMPtr<nsIXPConnect> xpconnect (do_GetService (nsIXPConnect::GetCID()));
+	NS_ENSURE_TRUE (xpconnect, PR_FALSE);
+
 	nsresult rv;
-	nsCOMPtr<nsIScriptSecurityManager> securityManager =
-			do_GetService(NS_SCRIPTSECURITYMANAGER_CONTRACTID, &rv);
+	nsCOMPtr<nsIXPCNativeCallContext> ncc;
+	rv = xpconnect->GetCurrentNativeCallContext (getter_AddRefs (ncc));
 	NS_ENSURE_SUCCESS (rv, PR_FALSE);
 
-	nsCOMPtr<nsIPrincipal> principal;
-	rv = securityManager->GetSubjectPrincipal (getter_AddRefs (principal));
+	if (!ncc) return PR_FALSE;
 
-	g_print ("rv=%x mPrincipal=%p\n", rv, (void*)principal.get());
-	return NS_SUCCEEDED (rv) && principal.get();
+	JSContext *cx = nsnull;
+	rv = ncc->GetJSContext (&cx);
+	g_print ("GetJSContext rv=%x, cx=%p\n", rv, cx);
+
+	NS_ENSURE_SUCCESS (rv, PR_FALSE);
+
+	return cx != nsnull;
 #endif
 	return PR_FALSE;
 }
@@ -579,14 +572,26 @@ Prompter::IsCalledFromScript()
 void
 Prompter::PerformScriptAbortion()
 {
-	/* FIXME: implement me! */
 #if 0
-	nsresult rv;
-	nsCOMPtr<nsIScriptSecurityManager> securityManager =
-			do_GetService(NS_SCRIPTSECURITYMANAGER_CONTRACTID, &rv);
-	NS_ENSURE_SUCCESS (rv, );
+	/* FIXME: can we only stop the calling script, not all scripts in the context? */
 
-	securityManager->DisableCapability ("javascript.enabled");
+	nsCOMPtr<nsIXPConnect> xpconnect (do_GetService (nsIXPConnect::GetCID()));
+	NS_ENSURE_TRUE (xpconnect, );
+
+	nsresult rv;
+	nsCOMPtr<nsIXPCNativeCallContext> ncc;
+	rv = xpconnect->GetCurrentNativeCallContext (getter_AddRefs (ncc));
+	NS_ENSURE_SUCCESS (rv, );
+	NS_ENSURE_TRUE (ncc, );
+
+	JSContext *cx = nsnull;
+	rv = ncc->GetJSContext (&cx);
+	g_print ("GetJSContext rv=%x, cx=%p\n", rv, cx);
+	NS_ENSURE_SUCCESS (rv, );
+	NS_ENSURE_TRUE (cx, );
+
+	g_print ("Would now disable scripts\n");
+//	MozillaPrivate::SetScriptsEnabled (cx, PR_FALSE, PR_FALSE);
 #endif
 }
 
@@ -604,7 +609,10 @@ Prompter::ConvertAndTruncateString (const PRUnichar *aText,
 	char *converted = g_utf16_to_utf8 ((gunichar2*) aText, aMaxLength,
 					    &n_read, &n_written, NULL);
 	/* FIXME loop from the end while !g_unichar_isspace (char)? */
+        if (!converted)
+                return NULL;
 
+        g_strdelimit (converted, "\001\002\003\004\005\006\007\010\011\012\013\014\015\016\017\020\021\022\023\024\025\026\027\030\031\032\033\034\035\036\037", ' ');
 	return converted;
 }
 
@@ -645,8 +653,12 @@ Prompter::ConvertAndEscapeButtonText(const PRUnichar *aText,
 	return escaped;
 }
 
-/* FIXME: needs THREADSAFE? */
-#if HAVE_NSINONBLOCKINGALERTSERVICE_H
+#ifdef HAVE_GECKO_1_9
+NS_IMPL_THREADSAFE_ISUPPORTS3 (EphyPromptService,
+                               nsIPromptService,
+                               nsIPromptService2,
+                               nsINonBlockingAlertService)
+#elif defined(HAVE_NSINONBLOCKINGALERTSERVICE_H)
 NS_IMPL_ISUPPORTS2 (EphyPromptService,
 		    nsIPromptService,
 		    nsINonBlockingAlertService)
@@ -675,9 +687,9 @@ EphyPromptService::Alert (nsIDOMWindow *aParent,
 {
 	Prompter prompt (GTK_STOCK_DIALOG_INFO, aParent, aDialogTitle, aText);
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
-	PRInt32 response = prompt.Run ();
+	prompt.Run ();
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* void alertCheck (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -692,10 +704,10 @@ EphyPromptService::AlertCheck (nsIDOMWindow *aParent,
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run ();
+	prompt.Run ();
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean confirm (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText); */
@@ -710,9 +722,9 @@ EphyPromptService::Confirm (nsIDOMWindow *aParent,
 	Prompter prompt (GTK_STOCK_DIALOG_QUESTION, aParent, aDialogTitle, aText);
 	prompt.AddStockButton (GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean confirmCheck (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -731,10 +743,10 @@ EphyPromptService::ConfirmCheck (nsIDOMWindow *aParent,
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* PRInt32 confirmEx (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in unsigned long aButtonFlags, in wstring aButton0Title, in wstring aButton1Title, in wstring aButton2Title, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -757,11 +769,10 @@ EphyPromptService::ConfirmEx (nsIDOMWindow *aParent,
 				    aButton1Title, aButton2Title);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (nsnull);
-	*_retval = response;
+	*_retval = prompt.Run (nsnull);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean prompt (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, inout wstring aValue, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -783,11 +794,11 @@ EphyPromptService::Prompt (nsIDOMWindow *aParent,
 	prompt.AddEntry (nsnull, *aValue, PR_FALSE);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetText (0, aValue);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean promptUsernameAndPassword (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, inout wstring aUsername, inout wstring aPassword, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -812,12 +823,12 @@ EphyPromptService::PromptUsernameAndPassword (nsIDOMWindow *aParent,
 	prompt.AddEntry (_("_Password:"), *aPassword, PR_TRUE);
 	prompt.AddCheckbox (aCheckMsg, aCheckState);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetText (0, aUsername);
 	prompt.GetText (1, aPassword);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean promptPassword (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, inout wstring aPassword, in wstring aCheckMsg, inout boolean aCheckState); */
@@ -841,11 +852,11 @@ EphyPromptService::PromptPassword (nsIDOMWindow *aParent,
 
 	// FIXME: Add a CAPSLOCK indicator?
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetText (0, aPassword);
 	prompt.GetCheckboxState (aCheckState);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 /* boolean select (in nsIDOMWindow aParent, in wstring aDialogTitle, in wstring aText, in PRUint32 aCount, [array, size_is (aCount)] in wstring aSelectList, out long aOutSelection); */
@@ -866,10 +877,10 @@ EphyPromptService::Select (nsIDOMWindow *aParent,
 	prompt.AddStockButton (GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
 	prompt.AddSelect (aCount, aSelectList, *aOutSelection);
 
-	PRInt32 response = prompt.Run (_retval);
+	prompt.Run (_retval);
 	prompt.GetSelected (aOutSelection);
 
-	return RETVAL(response);
+	return NS_OK;
 }
 
 #if HAVE_NSINONBLOCKINGALERTSERVICE_H
@@ -890,3 +901,218 @@ EphyPromptService::ShowNonBlockingAlert (nsIDOMWindow *aParent,
 }
 
 #endif /* HAVE_NSINONBLOCKINGALERTSERVICE_H */
+
+#ifdef HAVE_GECKO_1_9
+
+static void
+NS_GetAuthHostPort(nsIChannel* aChannel, nsIAuthInformation* aAuthInfo,
+                   PRBool machineProcessing, nsCString& host, PRInt32* port)
+{
+  nsCOMPtr<nsIURI> uri;
+  nsresult rv = aChannel->GetURI(getter_AddRefs(uri));
+  if (NS_FAILED(rv))
+    return;
+
+  // Have to distinguish proxy auth and host auth here...
+  PRUint32 flags;
+  aAuthInfo->GetFlags(&flags);
+  if (flags & nsIAuthInformation::AUTH_PROXY) {
+    nsCOMPtr<nsIProxiedChannel> proxied(do_QueryInterface(aChannel));
+    NS_ASSERTION(proxied, "proxy auth needs nsIProxiedChannel");
+
+    nsCOMPtr<nsIProxyInfo> info;
+    proxied->GetProxyInfo(getter_AddRefs(info));
+    NS_ASSERTION(info, "proxy auth needs nsIProxyInfo");
+
+    nsCAutoString idnhost;
+    info->GetHost(idnhost);
+    info->GetPort(port);
+
+    if (machineProcessing) {
+      nsCOMPtr<nsIIDNService> idnService =
+        do_GetService(NS_IDNSERVICE_CONTRACTID);
+      if (idnService) {
+        idnService->ConvertUTF8toACE(idnhost, host);
+      } else {
+        // Not much we can do here...
+        host = idnhost;
+      }
+    } else {
+      host = idnhost;
+    }
+  } else {
+    if (machineProcessing) {
+      uri->GetAsciiHost(host);
+      *port = NS_GetRealPort(uri);
+    } else {
+      uri->GetHost(host);
+      uri->GetPort(port);
+    }
+  }
+}
+
+static nsresult
+MakeDialogText(nsIChannel* aChannel, nsIAuthInformation* aAuthInfo,
+               nsString& message)
+{
+  nsresult rv;
+  nsCOMPtr<nsIStringBundleService> bundleSvc =
+    do_GetService(NS_STRINGBUNDLE_CONTRACTID, &rv);
+  NS_ENSURE_SUCCESS(rv, rv);
+
+  nsCOMPtr<nsIStringBundle> bundle;
+  rv = bundleSvc->CreateBundle("chrome://global/locale/prompts.properties",
+                               getter_AddRefs(bundle));
+  NS_ENSURE_SUCCESS(rv, rv);
+
+  // figure out what message to display...
+  nsCAutoString host;
+  PRInt32 port;
+  NS_GetAuthHostPort(aChannel, aAuthInfo, PR_FALSE, host, &port);
+
+  nsAutoString displayHost;
+  CopyUTF8toUTF16(host, displayHost);
+
+  nsCOMPtr<nsIURI> uri;
+  aChannel->GetURI(getter_AddRefs(uri));
+
+  nsCAutoString scheme;
+  uri->GetScheme(scheme);
+
+  nsAutoString username;
+  aAuthInfo->GetUsername(username);
+
+  PRUint32 flags;
+  aAuthInfo->GetFlags(&flags);
+  PRBool proxyAuth = (flags & nsIAuthInformation::AUTH_PROXY) != 0;
+
+  nsAutoString realm;
+  aAuthInfo->GetRealm(realm);
+
+  // Append the port if it was specified
+  if (port != -1) {
+    displayHost.Append(PRUnichar(':'));
+    displayHost.AppendInt(port);
+  }
+
+  NS_NAMED_LITERAL_STRING(proxyText, "EnterUserPasswordForProxy");
+  NS_NAMED_LITERAL_STRING(originText, "EnterUserPasswordForRealm");
+  NS_NAMED_LITERAL_STRING(noRealmText, "EnterUserPasswordFor");
+  NS_NAMED_LITERAL_STRING(passwordText, "EnterPasswordFor");
+
+  const PRUnichar *text;
+  if (proxyAuth) {
+    text = proxyText.get();
+  } else {
+    text = originText.get();
+
+    // prepend "scheme://"
+    nsAutoString schemeU; 
+    CopyASCIItoUTF16(scheme, schemeU);
+    schemeU.AppendLiteral("://");
+    displayHost.Insert(schemeU, 0);
+  }
+
+  const PRUnichar *strings[] = { realm.get(), displayHost.get() };
+  PRUint32 count = NS_ARRAY_LENGTH(strings);
+
+  if (flags & nsIAuthInformation::ONLY_PASSWORD) {
+    text = passwordText.get();
+    strings[0] = username.get();
+  } else if (!proxyAuth && realm.IsEmpty()) {
+    text = noRealmText.get();
+    count--;
+    strings[0] = strings[1];
+  }
+
+  rv = bundle->FormatStringFromName(text, strings, count, getter_Copies(message));
+  return rv;
+}
+
+/* static */ nsresult
+EphyPromptService::PromptPasswordAdapter(nsIPromptService* aService,
+					 nsIDOMWindow* aParent,
+					 nsIChannel* aChannel,
+					 PRUint32 aLevel,
+					 nsIAuthInformation* aAuthInfo,
+					 const PRUnichar* aCheckLabel,
+					 PRBool* aCheckValue,
+					 PRBool* retval)
+{
+  // construct the message string
+  nsString message;
+  MakeDialogText(aChannel, aAuthInfo, message);
+
+  nsAutoString defaultUser, defaultDomain, defaultPass;
+  aAuthInfo->GetUsername(defaultUser);
+  aAuthInfo->GetDomain(defaultDomain);
+  aAuthInfo->GetPassword(defaultPass);
+
+  PRUint32 flags;
+  aAuthInfo->GetFlags(&flags);
+
+  if ((flags & nsIAuthInformation::NEED_DOMAIN) && !defaultDomain.IsEmpty()) {
+    defaultDomain.Append(PRUnichar('\\'));
+    defaultUser.Insert(defaultDomain, 0);
+  }
+
+  // NOTE: Allocation failure is not fatal here (just default to empty string
+  // if allocation fails)
+  PRUnichar *user = ToNewUnicode(defaultUser),
+    *pass = ToNewUnicode(defaultPass);
+  nsresult rv;
+  if (flags & nsIAuthInformation::ONLY_PASSWORD)
+    rv = aService->PromptPassword(aParent, nsnull, message.get(),
+                                  &pass, aCheckLabel,
+                                  aCheckValue, retval);
+  else
+    rv = aService->PromptUsernameAndPassword(aParent, nsnull, message.get(),
+                                             &user, &pass, aCheckLabel,
+                                             aCheckValue, retval);
+
+  nsString userStr(user);
+  nsString passStr(pass);
+  aAuthInfo->SetUsername(userStr);
+  aAuthInfo->SetPassword(passStr);
+
+  return rv;
+}
+
+/* boolean promptAuth (in nsIDOMWindow aParent, in nsIChannel aChannel, in PRUint32 level, in nsIAuthInformation authInfo, in wstring checkboxLabel, inout boolean checkValue); */
+NS_METHOD
+EphyPromptService::PromptAuth(nsIDOMWindow *aParent,
+			      nsIChannel *aChannel,
+			      PRUint32 level,
+			      nsIAuthInformation *authInfo,
+			      const PRUnichar *checkboxLabel,
+			      PRBool *checkValue,
+			      PRBool *_retval)
+{
+  NS_ENSURE_ARG_POINTER (_retval);
+  NS_ENSURE_ARG_POINTER (authInfo);
+
+  return EphyPromptService::PromptPasswordAdapter(this,
+						  aParent,
+						  aChannel,
+						  level,
+						  authInfo,
+						  checkboxLabel,
+						  checkValue,
+						  _retval);
+}
+
+/* nsICancelable asyncPromptAuth (in nsIDOMWindow aParent, in nsIChannel aChannel, in nsIAuthPromptCallback aCallback, in nsISupports aContext, in PRUint32 level, in nsIAuthInformation authInfo, in wstring checkboxLabel, inout boolean checkValue); */
+NS_METHOD EphyPromptService::AsyncPromptAuth(nsIDOMWindow *aParent,
+					     nsIChannel *aChannel,
+					     nsIAuthPromptCallback *aCallback,
+					     nsISupports *aContext,
+					     PRUint32 level,
+					     nsIAuthInformation *authInfo,
+					     const PRUnichar *checkboxLabel,
+					     PRBool *checkValue,
+					     nsICancelable **_retval)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+#endif /* HAVE_GECKO_1_9 */
