@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-node-view.h,v 1.17.10.1 2006/09/13 11:48:49 chpe Exp $
+ *  $Id: ephy-node-view.h 7762 2007-12-08 01:21:52Z cosimoc $
  */
 
 #ifndef __EPHY_NODE_VIEW_H
@@ -58,7 +58,8 @@ typedef enum
 	EPHY_NODE_VIEW_SHOW_PRIORITY = 1 << 0,
 	EPHY_NODE_VIEW_SORTABLE = 1 << 1,
 	EPHY_NODE_VIEW_EDITABLE = 1 << 2,
-	EPHY_NODE_VIEW_SEARCHABLE = 1 << 3
+	EPHY_NODE_VIEW_SEARCHABLE = 1 << 3,
+	EPHY_NODE_VIEW_ELLIPSIZED = 1 << 4
 } EphyNodeViewFlags;
 
 typedef struct
@@ -69,6 +70,7 @@ typedef struct
 	void (*node_activated)      (EphyNodeView *view, EphyNode *node);
 	void (*node_selected)       (EphyNodeView *view, EphyNode *node);
 	void (*node_dropped)        (EphyNodeView *view, EphyNode *node, GList *uris);
+	void (*node_middle_clicked) (EphyNodeView *view, EphyNode *node);
 } EphyNodeViewClass;
 
 GType      ephy_node_view_get_type	      (void);
